(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    106290,       2945]
NotebookOptionsPosition[     97346,       2789]
NotebookOutlinePosition[     97758,       2805]
CellTagsIndexPosition[     97715,       2802]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Decays V \[Rule] 3\[Pi]", "Title",
 CellChangeTimes->{{3.8279037563802757`*^9, 
  3.827903771441114*^9}},ExpressionUUID->"8edda97e-8cfc-496f-b52d-\
45bda659245b"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "We", " ", "want", " ", "to", " ", "confirm", " ", "some", " ", 
      "calculations", " ", "from"}], " ", "<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"1203.2501", ".", "pdf"}]}], ">"}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "in", " ", "particular", " ", "the", " ", "discontinuity", " ", 
     "obtained", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", 
      RowBox[{"(", "13", ")"}]}]}], ";", " ", 
    RowBox[{
    "see", " ", "also", " ", "the", " ", "corresponding", " ", "handwritten", 
     " ", 
     RowBox[{"notes", "."}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8279037738595467`*^9, 3.827903806342417*^9}, {
  3.828415688987638*^9, 
  3.828415699310207*^9}},ExpressionUUID->"2931db4e-1d93-4bff-88fa-\
b67d831e257d"],

Cell[CellGroupData[{

Cell["Kinematics", "Section",
 CellChangeTimes->{{3.827903827943522*^9, 
  3.827903833798012*^9}},ExpressionUUID->"dc64ec20-ed38-4b6d-acca-\
37488d9e6618"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Note", " ", "that", " ", "instead", " ", "of", " ", "V"}], " ", 
    "\[Rule]", " ", 
    RowBox[{"3", "\[Pi]"}]}], ",", " ", 
   RowBox[{
    RowBox[{"we", " ", "consider", " ", "V\[Pi]"}], " ", "\[Rule]", " ", 
    RowBox[{"\[Pi]\[Pi]", " ", "in", " ", "the", " ", 
     RowBox[{"following", "."}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.827903864884665*^9, 
  3.827903878657364*^9}},ExpressionUUID->"6246f7aa-8893-4fa1-beca-\
c664aaada592"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Useful", " ", "functions", " ", "and", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", 
         SuperscriptBox["M\[Pi]", "2"]}], "s"]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "x", " ", "y"}], "-", 
      RowBox[{"2", "x", " ", "z"}], "-", 
      RowBox[{"2", "y", " ", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903905253169*^9, 3.827903929561741*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"b1d22be1-127e-4293-8c2f-ed4f8fcd7c51"],

Cell[CellGroupData[{

Cell["Energies and Momenta in the CMS", "Subsection",
 CellChangeTimes->{{3.827904609235016*^9, 
  3.827904619765608*^9}},ExpressionUUID->"0d338ae3-42ef-4591-ba2b-\
4c8e9c2c4c6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "initial"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["MV", "2"], "+", 
         SuperscriptBox["p", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["M\[Pi]", "2"], "+", 
         SuperscriptBox["p", "2"]}]]}]}], ",", "p"}], "]"}], "\n", 
   RowBox[{
    RowBox[{"pInitial", "=", 
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["MV", "2"], ",", 
         SuperscriptBox["M\[Pi]", "2"]}], "]"}]], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pInitial", "2"], "+", 
       SuperscriptBox["MV", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pInitial", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1Initial", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["MV", "2"], "-", 
         SuperscriptBox["M\[Pi]", "2"]}], ")"}], "+", "s"}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], " ", ";"}], "\n", 
   RowBox[{
    RowBox[{"E2Initial", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["MV", "2"], "-", 
         SuperscriptBox["M\[Pi]", "2"]}], ")"}], "-", "s"}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], " ", ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903852339466*^9, 3.827903900304286*^9}, {
  3.827903959400042*^9, 3.827904063392894*^9}, {3.827904093680064*^9, 
  3.827904193650341*^9}, {3.827904566996336*^9, 3.8279045674535217`*^9}, {
  3.827905542892358*^9, 3.827905555461874*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"0c523243-59aa-4495-aedd-c82b0b0cf463"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["M\[Pi]", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
          SuperscriptBox["MV", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", 
           SuperscriptBox["MV", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["MV", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", 
         SqrtBox["s"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["M\[Pi]", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
         SuperscriptBox["MV", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", 
          SuperscriptBox["MV", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["MV", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.827904008543831*^9, 3.82790419473179*^9, 
  3.82790517845496*^9, 3.828417415698429*^9, 3.828532223444326*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"de00e585-0964-4aa6-a44c-6781b36562d7"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["M\[Pi]", "2"]}], "+", 
        SuperscriptBox["MV", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.827904008543831*^9, 3.82790419473179*^9, 
  3.82790517845496*^9, 3.828417415698429*^9, 3.8285322234581623`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"c484e758-cb74-4d71-8136-30911bf4f477"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", 
        SuperscriptBox["MV", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.827904008543831*^9, 3.82790419473179*^9, 
  3.82790517845496*^9, 3.828417415698429*^9, 3.828532223508065*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"fe7d861b-ce04-479b-8e86-bd2d156d7fcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "intermediate"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pIntermediate", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], "\[Sigma]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pIntermediate", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EIntermediate", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903616797558*^9, 3.827903637128743*^9}, {
  3.8279038429393663`*^9, 3.8279038503343287`*^9}, {3.8279041991672707`*^9, 
  3.827904233782255*^9}, {3.827904442294922*^9, 3.8279044937606897`*^9}, {
  3.8279045637334948`*^9, 3.827904564502139*^9}, {3.8279055603344717`*^9, 
  3.827905562537691*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"d831104f-b9bf-48e9-b9db-3a129a0316a5"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.827903635774776*^9, 3.8279036375875683`*^9}, {
   3.8279044889415483`*^9, 3.827904495585883*^9}, 3.8279051785688667`*^9, 
   3.828417419275041*^9, 3.828532223530045*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"da9987df-a3fc-4dfe-b80e-69e6f09d9f79"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.827903635774776*^9, 3.8279036375875683`*^9}, {
   3.8279044889415483`*^9, 3.827904495585883*^9}, 3.8279051785688667`*^9, 
   3.828417419275041*^9, 3.8285322235384893`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"cca7260d-5003-400a-a350-c267e94c49cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "final"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pFinal", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], "\[Sigma]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pFinal", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EFinal", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903616797558*^9, 3.827903637128743*^9}, {
  3.8279038429393663`*^9, 3.8279038503343287`*^9}, {3.8279041991672707`*^9, 
  3.827904233782255*^9}, {3.827904442294922*^9, 3.8279044937606897`*^9}, {
  3.827904559943368*^9, 3.8279045973705053`*^9}, {3.827905565392714*^9, 
  3.827905566054056*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"8b3ea4c8-ffd2-4a08-bb10-07d64f07a2d2"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.827903635774776*^9, 3.8279036375875683`*^9}, {
   3.8279044889415483`*^9, 3.827904495585883*^9}, 3.827904597719914*^9, 
   3.827905178802655*^9, 3.8284174216427307`*^9, 3.828532223592683*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"cb57bd3e-2527-4527-9241-e0351d9c34fc"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.827903635774776*^9, 3.8279036375875683`*^9}, {
   3.8279044889415483`*^9, 3.827904495585883*^9}, 3.827904597719914*^9, 
   3.827905178802655*^9, 3.8284174216427307`*^9, 3.82853222359814*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"26b0939d-ab63-4a99-91d6-6c8671ed136d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Taking the Angles into Account", "Subsection",
 CellChangeTimes->{{3.827904625683963*^9, 3.8279046349027147`*^9}, {
  3.8279055817614937`*^9, 
  3.827905585196157*^9}},ExpressionUUID->"75c59fb5-d130-4b8a-aad3-\
eed703cf8fd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"82136410-855c-4667-abc6-1a1943bb156e"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (development version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (development version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828532231057322*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"797e3dc4-c978-4beb-9879-b380b06128d9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828532231073934*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"8b25194d-4913-426c-9699-1a4ad147515f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828532231080124*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"0d66a81a-adac-46ec-aa97-5a24dd6e9220"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828532231086813*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"eae08e53-f31f-4cc9-a0c3-a952eeda8764"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828532231091921*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"c8feefdf-496a-4af2-a57f-4a36ff128c33"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.8285322310978813`*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"91e6fcfd-6041-4ec8-8d7b-e64f0195334a"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "scalar", " ", "products", " ", "needed", " ", "to", " ", 
    "evaluate", " ", "the", " ", "below", " ", 
    RowBox[{"expressions", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pp", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pm", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"pp", ",", "pm"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s", "-", 
       RowBox[{"2", 
        SuperscriptBox["M\[Pi]", "2"]}]}], "2"]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p0", ",", "pp"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EFinal"}], "+", 
      RowBox[{"pInitial", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p0", ",", "pm"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EFinal"}], "-", 
      RowBox[{"pInitial", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"l", ",", "pp"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIntermediate", "*", "EFinal"}], "+", 
      RowBox[{"pIntermediate", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "''"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"l", ",", "pm"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIntermediate", "*", "EFinal"}], "-", 
      RowBox[{"pIntermediate", "*", "pFinal", "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "''"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"l", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EIntermediate"}], "-", 
      RowBox[{"pInitial", "*", "pIntermediate", "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "'"}], "]"}]}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827904709429264*^9, 3.827904754690968*^9}, {
  3.827904972567852*^9, 3.8279050069647713`*^9}, {3.8279050450833883`*^9, 
  3.8279050829883413`*^9}, {3.827905123881398*^9, 3.827905128181974*^9}, {
  3.827905196085853*^9, 3.827905200178224*^9}, {3.8279053365394487`*^9, 
  3.82790544651763*^9}, {3.827905630760065*^9, 3.827905640732544*^9}, {
  3.827906047789406*^9, 3.827906066097209*^9}, {3.8279061169474154`*^9, 
  3.82790613164476*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"a65d4b1a-5aa3-4286-8393-6f04b911490f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discontinuity", "Section",
 CellChangeTimes->{{3.827914876578225*^9, 
  3.827914882298044*^9}},ExpressionUUID->"02f35dc7-29ed-42b6-ab80-\
be8ece5b3f84"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "left"}], "-", 
    RowBox[{
    "hand", " ", "side", " ", "of", " ", "the", " ", "equation", " ", 
     "obtained", " ", "on", " ", "the", " ", "handwritten", " ", 
     RowBox[{"notes", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pp", ",", "\[Nu]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pm", ",", "\[Alpha]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p0", ",", "\[Beta]"}], "]"}], 
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]2"}], 
      "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pp", ",", "\[Nu]2"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pm", ",", "\[Alpha]2"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p0", ",", "\[Beta]2"}], "]"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8279056112472563`*^9, 3.8279056141090517`*^9}, {
   3.8279057996288433`*^9, 3.827905800025723*^9}, 3.827908754465046*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"54470584-aeeb-41ba-ba98-d60c8b1ac79d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{
    SuperscriptBox["sin", "2"], "(", "\[Theta]", ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], ")"}], "2"], "+", 
     SuperscriptBox["MV", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["MV", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.827905458617852*^9, 3.827905803589355*^9, 
  3.827906076932892*^9, 3.827906133309074*^9, 3.827908759019972*^9, 
  3.828417432448399*^9, 3.82853223220393*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"ebd5f9fd-b89b-41c0-ba8e-090397a6fe71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "right"}], "-", 
    RowBox[{
    "hand", " ", "side", " ", "of", " ", "the", " ", "equation", " ", 
     "obtained", " ", "on", " ", "the", " ", "handwritten", " ", 
     RowBox[{"notes", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{
       RowBox[{"pp", "+", "pm"}], ",", "\[Nu]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"l", ",", "\[Alpha]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p0", ",", "\[Beta]"}], "]"}], 
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]2"}], 
      "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pp", ",", "\[Nu]2"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"pm", ",", "\[Alpha]2"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p0", ",", "\[Beta]2"}], "]"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.82775020228656*^9, 3.827750249778994*^9}, {
   3.82790531137617*^9, 3.827905320582491*^9}, {3.827905588524118*^9, 
   3.827905608160315*^9}, {3.827905801721098*^9, 3.827905802285475*^9}, 
   3.827908757756338*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"3ed7efb6-dbe9-44af-bbc5-34bbf8c68833"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], ")"}], "2"], "+", 
     SuperscriptBox["MV", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["MV", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"cos", "(", "\[Theta]", ")"}], " ", 
      RowBox[{"cos", "(", 
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], ")"}]}], "-", 
     RowBox[{"cos", "(", 
      SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
       MultilineFunction->None], ")"}]}], ")"}]}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.8277502474108*^9, 3.82775025007401*^9}, 
   3.827905145056888*^9, {3.8279051929089108`*^9, 3.827905202436736*^9}, 
   3.827905322637269*^9, 3.8279054613223877`*^9, 3.827905802679241*^9, 
   3.827906078199419*^9, 3.8279061348818893`*^9, 3.827908758127369*^9, 
   3.828417434369915*^9, 3.828532235576544*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"22612353-88af-4454-862b-e0750d2d89ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "resulting", " ", "factor", " ", "on", " ", "the", " ", 
    RowBox[{"RHS", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "'"}], "]"}]}], "-", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "''"}], "]"}]}], 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Theta]1", "]"}], "2"]}]]}]}]], "Input",
 CellChangeTimes->{{3.827905806172017*^9, 3.8279058233931503`*^9}, {
  3.8279058610481863`*^9, 3.827905866040681*^9}, {3.827905899258215*^9, 
  3.82790595873378*^9}, {3.8279060843239326`*^9, 3.827906090578795*^9}, {
  3.827906139317635*^9, 3.827906162612157*^9}, {3.8279127110491047`*^9, 
  3.827912713130741*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"a59187d0-b15b-4926-8e5d-5ed22a517b7c"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"cos", "(", "\[Theta]", ")"}], " ", 
      RowBox[{"cos", "(", 
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], ")"}]}], "-", 
     RowBox[{"cos", "(", 
      SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
       MultilineFunction->None], ")"}]}], 
    RowBox[{"1", "-", 
     RowBox[{
      SuperscriptBox["cos", "2"], "(", "\[Theta]1", ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.827905818308897*^9, 3.827905823648267*^9}, 
   3.827905867575383*^9, {3.8279059016281567`*^9, 3.827905911116376*^9}, 
   3.8279059591730833`*^9, 3.827906094103508*^9, 3.827906164321217*^9, 
   3.8284174359607773`*^9, 3.828532236837727*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"f02ecdad-caed-48d0-bd7b-6751e6d6bf16"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Project out the L=1 partial wave", "Section",
 CellChangeTimes->{{3.827914848557863*^9, 
  3.8279148919112062`*^9}},ExpressionUUID->"33734ebc-350e-4086-a23e-\
26078219fe39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Using", " ", "the", " ", "Legendre", " ", "polynomials"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"we", " ", "project", " ", "out", " ", "the", " ", "L"}], "=", 
     RowBox[{
     "1", " ", "partial", " ", "wave", " ", "from", " ", "the", " ", 
      "obtained", " ", "discontinuity", " ", 
      RowBox[{"equation", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zsPP", "=", 
     RowBox[{
      RowBox[{"zs", "*", "zsP"}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["zs", "2"]}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["zsP", "2"]}]], 
       RowBox[{"Cos", "[", "\[Phi]sP", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"LegendreP", "[", 
           RowBox[{"0", ",", "zs"}], "]"}], "-", 
          RowBox[{"LegendreP", "[", 
           RowBox[{"2", ",", "zs"}], "]"}]}], ")"}], 
        FractionBox[
         RowBox[{"zsPP", "-", 
          RowBox[{"zs", "*", "zsP"}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["zs", "2"]}]], "*", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"LegendreP", "[", 
           RowBox[{"i", ",", "zsP"}], "]"}], ",", "zsP"}], "]"}], 
        RowBox[{"LegendreP", "[", 
         RowBox[{"j", ",", "zsPP"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"zs", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zsP", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]sP", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "5"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8279148940950947`*^9, 3.827914930979411*^9}, 
   3.827916880956167*^9, {3.8279258198578653`*^9, 3.8279258238669147`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"a9879273-914a-4072-b456-988d473abb21"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"8", " ", "\[Pi]"}], "3"], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.827925988719759*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"799d062c-55e2-4484-b71d-160e87fe3703"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "same", " ", "but", " ", "with", " ", "the", " ", "expression",
     " ", "further", " ", "simplified", " ", "by", " ", 
    RowBox[{"hand", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"0", ",", "zs"}], "]"}], "-", 
         RowBox[{"LegendreP", "[", 
          RowBox[{"2", ",", "zs"}], "]"}]}], ")"}], 
       SqrtBox[
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["zsP", "2"]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["zs", "2"]}]]], 
       RowBox[{"Cos", "[", "\[Phi]sP", "]"}], "*", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"i", ",", "zsP"}], "]"}], ",", "zsP"}], "]"}], 
       RowBox[{"LegendreP", "[", 
        RowBox[{"j", ",", "zsPP"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"zs", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"zsP", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Phi]sP", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.827926411541951*^9, 3.8279264305664988`*^9}, {
  3.827977959473236*^9, 
  3.827977979778162*^9}},ExpressionUUID->"40761ede-e6b2-4a9d-b199-\
db08f64bde40"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"8", " ", "\[Pi]"}], "3"], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.827926551666548*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"0d3757d0-8916-4289-addf-f8feb25423d9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inhomogeneity", "Section",
 CellChangeTimes->{{3.827991714849605*^9, 
  3.827991723457984*^9}},ExpressionUUID->"6ed9556a-46d7-4e9f-b685-\
443e4e689f74"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "We", " ", "give", " ", "the", " ", "inhomogeneity", " ", "of", " ", 
      "the", " ", "integral", " ", "equation", " ", "in", " ", "terms", " ", 
      "of", " ", "the", " ", "form", " ", "factor"}], ";", " ", "here"}], ",",
     " ", 
    RowBox[{
     RowBox[{"we", " ", "only", " ", "calculate", " ", "the", " ", "s"}], "-", 
     RowBox[{"channel", " ", "part"}]}], ",", " ", 
    RowBox[{"while", " ", "the", " ", "rest", " ", "remains", " ", 
     RowBox[{"undetermined", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   FractionBox["3", "4"], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["z", "2"]}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.827991733819199*^9, 3.827991775605188*^9}, {
  3.827991976058236*^9, 3.827991998013445*^9}, {3.827993566652608*^9, 
  3.8279935855974894`*^9}, {3.828002330508525*^9, 
  3.828002341271731*^9}},ExpressionUUID->"9af5e80b-766c-4c1c-acbc-\
b2c3c2aaac85"],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellChangeTimes->{3.8279935864073963`*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"a68bc149-598f-4eba-b57d-54da0f914d8d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Higher Partial Waves (F-waves)", "Section",
 CellChangeTimes->{{3.828155686427806*^9, 
  3.828155717023362*^9}},ExpressionUUID->"65740e1b-ef99-4e57-ad42-\
b67052d253f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Note", " ", "that", " ", 
      RowBox[{"(", 
       RowBox[{"in", " ", "general"}], ")"}], " ", "the", " ", "t"}], "-", 
     " ", 
     RowBox[{"und", " ", "u"}], "-", 
     RowBox[{"channel", " ", "P"}], "-", 
     RowBox[{
     "wave", " ", "amplitudes", " ", "yield", " ", "contributions", " ", "to",
       " ", "the", " ", "s"}], "-", 
     RowBox[{"channel", " ", "F"}], "-", "wave"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "while", " ", "the", " ", "contribution", " ", "from", " ", "the", " ", 
       "s"}], "-", 
      RowBox[{"channel", " ", "vanishes"}]}], ".."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["7", "16"]}], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", 
        SuperscriptBox["z", "4"]}], "-", 
       RowBox[{"6", 
        SuperscriptBox["z", "2"]}], "+", "1"}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.828156558468341*^9, 3.828156593279735*^9}, {
  3.8281568482651033`*^9, 3.828156903376072*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"be7a42aa-5f0b-46df-a96e-b1f118922af5"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.828156903922708*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"8de141c1-354b-46b6-a36b-03fe52078f10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Using", " ", "the", " ", "Legendre", " ", "polynomials"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"we", " ", "project", " ", "out", " ", "the", " ", "L"}], "=", 
     RowBox[{
     "3", " ", "partial", " ", "wave", " ", "from", " ", "the", " ", 
      "obtained", " ", "discontinuity", " ", 
      RowBox[{"equation", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"zsPP", "=", 
     RowBox[{
      RowBox[{"zs", "*", "zsP"}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["zs", "2"]}]], 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["zsP", "2"]}]], 
       RowBox[{"Cos", "[", "\[Phi]sP", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"LegendreP", "[", 
           RowBox[{"2", ",", "zs"}], "]"}], "-", 
          RowBox[{"LegendreP", "[", 
           RowBox[{"4", ",", "zs"}], "]"}]}], ")"}], 
        FractionBox[
         RowBox[{"zsPP", "-", 
          RowBox[{"zs", "*", "zsP"}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["zs", "2"]}]], "*", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"LegendreP", "[", 
           RowBox[{"i", ",", "zsP"}], "]"}], ",", "zsP"}], "]"}], 
        RowBox[{"LegendreP", "[", 
         RowBox[{"j", ",", "zsPP"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"zs", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zsP", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]sP", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "5"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.828155710596344*^9, 3.828155723910606*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"01af6bc1-0484-4fb3-b1c7-0c9a40f69d19"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox[
       RowBox[{"8", " ", "\[Pi]"}], "7"], "0", "0"},
     {"0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.8281558796856127`*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"4e038b5a-e174-417b-b8fc-d68b55111f3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Obtaining", " ", "the", " ", 
    RowBox[{"inhomogeneities", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"P", "-", 
    RowBox[{"Wave", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox["3", "4"], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    FractionBox["3", "4"], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["z", "2"]}], ")"}], 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"3", ",", "z"}], "]"}], ",", "z"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"F", "-", 
     RowBox[{"Wave", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "16"]}], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", 
          SuperscriptBox["z", "4"]}], "-", 
         RowBox[{"6", 
          SuperscriptBox["z", "2"]}], "+", "1"}], ")"}], "1"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "16"]}], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", 
          SuperscriptBox["z", "4"]}], "-", 
         RowBox[{"6", 
          SuperscriptBox["z", "2"]}], "+", "1"}], ")"}], 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"3", ",", "z"}], "]"}], ",", "z"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8281588453773623`*^9, 3.828158920396036*^9}, {
  3.828161528572756*^9, 3.828161555964938*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"1aec6083-bdc8-48d8-92aa-2b9e3d8cb489"],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281589220753937`*^9, {3.828161548588853*^9, 3.8281615564409533`*^9}},
 CellLabel->
  "Out[103]=",ExpressionUUID->"f33487fd-f652-4591-80c8-d60379ab6e79"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281589220753937`*^9, {3.828161548588853*^9, 3.828161556506487*^9}},
 CellLabel->
  "Out[104]=",ExpressionUUID->"5ecdb35e-6669-422b-97a4-3d3579161a1a"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281589220753937`*^9, {3.828161548588853*^9, 3.828161556511475*^9}},
 CellLabel->
  "Out[105]=",ExpressionUUID->"6181529f-1152-4953-8a28-c3af1aa203c7"],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281589220753937`*^9, {3.828161548588853*^9, 3.828161556530896*^9}},
 CellLabel->
  "Out[106]=",ExpressionUUID->"8c1b5abb-6856-4a77-8278-952c39714ca2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Rho]", "3"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "3f51c829-e883-497f-a5e5-94298e18920e"],
 " Contribution to the G(s) of \[Omega] \[Rule] 3\[Pi]"
}], "Section",
 CellChangeTimes->{{3.828417140520697*^9, 3.828417162201585*^9}, {
  3.82841720550909*^9, 3.828417213459271*^9}, {3.828426045300149*^9, 
  3.8284260503206377`*^9}},ExpressionUUID->"3b9fbab5-24e3-45f6-8d03-\
8cdf20ee57c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"b1b0216a-fc89-4fc1-b18f-ac77f3c820ef"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (development version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (development version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.8284332370925303`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"38091af1-4e2e-4f97-b5f4-311fafd1d185"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.8284332371023293`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"c450ff93-6164-47f9-9b2d-684954385ea7"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.8284332371097927`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"5a3ca59e-8fb1-4957-970f-cd5efaca09a2"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828433237113082*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"56466836-29c3-41f3-9977-235ce98b4b91"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.82843323711775*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"dca2caec-9e99-4e44-b796-80cccd03cb05"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.8279051566936207`*^9, 3.82790518533226*^9}, 
   3.828417427059669*^9, 3.828433237119437*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"b9ab5705-82d0-4568-9993-8ff789872872"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "scalar", " ", "products", " ", "needed", " ", "to", " ", 
    "evaluate", " ", "the", " ", "expressions", " ", 
    RowBox[{"below", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pp", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pm", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"pp", ",", "pm"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s", "-", 
       RowBox[{"2", 
        SuperscriptBox["M\[Pi]", "2"]}]}], "2"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p0", ",", "pp"}], "]"}], "=", 
     FractionBox[
      RowBox[{"u", "-", 
       RowBox[{"2", 
        SuperscriptBox["M\[Pi]", "2"]}]}], "2"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p0", ",", "pm"}], "]"}], "=", 
     FractionBox[
      RowBox[{"t", "-", 
       RowBox[{"2", 
        SuperscriptBox["M\[Pi]", "2"]}]}], "2"]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["MV", "2"], "+", 
       RowBox[{"3", 
        SuperscriptBox["M\[Pi]", "2"]}], "-", "s", "+", 
       RowBox[{"\[Kappa]", " ", "z"}]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"u", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["MV", "2"], "+", 
       RowBox[{"3", 
        SuperscriptBox["M\[Pi]", "2"]}], "-", "s", "-", 
       RowBox[{"\[Kappa]", " ", "z"}]}], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827904709429264*^9, 3.827904754690968*^9}, {
  3.827904972567852*^9, 3.8279050069647713`*^9}, {3.8279050450833883`*^9, 
  3.8279050829883413`*^9}, {3.827905123881398*^9, 3.827905128181974*^9}, {
  3.827905196085853*^9, 3.827905200178224*^9}, {3.8279053365394487`*^9, 
  3.82790544651763*^9}, {3.827905630760065*^9, 3.827905640732544*^9}, {
  3.827906047789406*^9, 3.827906066097209*^9}, {3.8279061169474154`*^9, 
  3.82790613164476*^9}, {3.8284331055190363`*^9, 3.828433107175559*^9}, {
  3.8284331454329576`*^9, 3.828433222202229*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"5c280818-6d7a-4146-aec5-55c465ba2f43"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Pauli", " ", "matrices", " ", "for", " ", "the", " ", "isospin", " ", 
    RowBox[{"fields", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Tau]1", "=", 
     RowBox[{"(", GridBox[{
        {"0", "1"},
        {"1", "0"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Tau]2", "=", 
     RowBox[{"(", GridBox[{
        {"0", 
         RowBox[{"-", "\[ImaginaryI]"}]},
        {"\[ImaginaryI]", "0"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Tau]3", "=", 
     RowBox[{"(", GridBox[{
        {"1", "0"},
        {"0", 
         RowBox[{"-", "1"}]}
       }], ")"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.828418288130701*^9, 3.8284183630640697`*^9}, {
  3.828421830852008*^9, 3.828421839166987*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"adb2ccde-9ddf-4444-b155-5542fb001556"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "isospin", " ", 
    RowBox[{"fields", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Rho]Field", "=", 
     RowBox[{
      RowBox[{"\[Rho]Field1", "*", "\[Tau]1"}], "+", 
      RowBox[{"\[Rho]Field2", "*", "\[Tau]2"}], "+", 
      RowBox[{"\[Rho]Field3", "*", "\[Tau]3"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Pi]Field", "=", 
     RowBox[{
      RowBox[{"\[Pi]Field1", "*", "\[Tau]1"}], "+", 
      RowBox[{"\[Pi]Field2", "*", "\[Tau]2"}], "+", 
      RowBox[{"\[Pi]Field3", "*", "\[Tau]3"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Pi]FieldD\[Mu]D\[Alpha]", "=", 
     RowBox[{
      RowBox[{"\[Pi]FieldD\[Mu]D\[Alpha]1", "*", "\[Tau]1"}], "+", 
      RowBox[{"\[Pi]FieldD\[Mu]D\[Alpha]2", "*", "\[Tau]2"}], "+", 
      RowBox[{"\[Pi]FieldD\[Mu]D\[Alpha]3", "*", "\[Tau]3"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Pi]FieldD\[Mu]", "=", 
     RowBox[{
      RowBox[{"\[Pi]FieldD\[Mu]1", "*", "\[Tau]1"}], "+", 
      RowBox[{"\[Pi]FieldD\[Mu]2", "*", "\[Tau]2"}], "+", 
      RowBox[{"\[Pi]FieldD\[Mu]3", "*", "\[Tau]3"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Pi]FieldD\[Nu]D\[Lambda]", "=", 
     RowBox[{
      RowBox[{"\[Pi]FieldD\[Nu]D\[Lambda]1", "*", "\[Tau]1"}], "+", 
      RowBox[{"\[Pi]FieldD\[Nu]D\[Lambda]2", "*", "\[Tau]2"}], "+", 
      RowBox[{"\[Pi]FieldD\[Nu]D\[Lambda]3", "*", "\[Tau]3"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.828418370833675*^9, 3.828418425481826*^9}, {
  3.828418466460444*^9, 3.8284184811020308`*^9}, {3.828419298182169*^9, 
  3.828419378486734*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"9f4eb6fe-f6e3-41e8-957b-b91c5cf44ae1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "the", " ", "commutator", " ", "as", " ", "we", " ", "need",
     " ", "it", " ", "for", " ", "the", " ", 
    RowBox[{"Lagrangian", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Comm", "[", 
     RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a", ".", "b"}], "-", 
     RowBox[{"b", ".", "a"}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.828419533833914*^9, 3.828419544502553*^9}, {
  3.828421752068049*^9, 3.828421754923942*^9}, {3.828421812179854*^9, 
  3.828421820836814*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"d9c26f88-75ef-4e44-a06a-e9ca3ed8c62c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "two", " ", "needed", " ", "traces", " ", "for", " ", "the", 
    " ", 
    RowBox[{"Lagrangian", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"\[Rho]Field", "*", "\[Pi]FieldD\[Mu]D\[Alpha]"}], "]"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"\[Rho]Field", "*", 
      RowBox[{"Comm", "[", 
       RowBox[{"\[Pi]FieldD\[Mu]", ",", "\[Pi]FieldD\[Nu]D\[Lambda]"}], 
       "]"}]}], "]"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.828418196910022*^9, 3.828418282526887*^9}, {
  3.828418430101549*^9, 3.8284184440626574`*^9}, {3.828418494562633*^9, 
  3.82841851945965*^9}, {3.828419384168726*^9, 3.828419447929777*^9}, {
  3.828419519495263*^9, 3.828419532060761*^9}, {3.828421790652121*^9, 
  3.8284217933255453`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"fe55d74f-e8fc-4347-a4be-cb97198f4f0c"],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[Pi]FieldD\[Mu]D\[Alpha]3", " ", "\[Rho]Field3"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828419400547391*^9, 3.828419451098619*^9, {3.828419528396886*^9, 
   3.828419545980986*^9}, 3.8284217571337557`*^9, 3.8284217935750504`*^9, 
   3.8284332490347223`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"5a85ce11-0c20-4da4-ae2b-f6f2d851d17f"],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
     "\[Pi]FieldD\[Mu]1", " ", "\[Pi]FieldD\[Nu]D\[Lambda]2", " ", 
      "\[Rho]Field3"}], "-", 
     RowBox[{
     "\[Pi]FieldD\[Mu]2", " ", "\[Pi]FieldD\[Nu]D\[Lambda]1", " ", 
      "\[Rho]Field3"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828419400547391*^9, 3.828419451098619*^9, {3.828419528396886*^9, 
   3.828419545980986*^9}, 3.8284217571337557`*^9, 3.8284217935750504`*^9, 
   3.82843324906524*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"440a1b39-c88c-4e9e-a44e-bd7de36e53e5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "polarization", " ", "sum", " ", "for", " ", "massive", " ", 
     "spin"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P3", "[", 
      RowBox[{
      "\[Mu]1_", ",", "\[Mu]2_", ",", "\[Mu]3_", ",", "\[Nu]1_", ",", 
       "\[Nu]2_", ",", "\[Nu]3_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       FractionBox["1", "6"], 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]1", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]2", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]3", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "]"}]}], "}"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "30"], 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]3", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "]"}]}], "}"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "30"], 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]1", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "]"}]}], "}"}]}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "30"], 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{"\[Mu]2", ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"X", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"Permutations", "[", 
              RowBox[{"{", 
               RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}],
              "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "]"}]}], "}"}]}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "polarization", " ", "sum", " ", "for", " ", "massive", " ", 
      "spin"}], "-", 
     RowBox[{"1", " ", 
      RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"MT", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"FV", "[", 
         RowBox[{
          RowBox[{"pp", "+", "pm"}], ",", "\[Alpha]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{
          RowBox[{"pp", "+", "pm"}], ",", "\[Beta]"}], "]"}]}], 
       SuperscriptBox["M\[Rho]", "2"]]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8284172572789717`*^9, 3.828417257764089*^9}, {
  3.8284174699709*^9, 3.828417472748334*^9}, {3.828417530580463*^9, 
  3.8284175379037037`*^9}, {3.8284176071036987`*^9, 3.8284176073958282`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"bf81b9fe-8589-43db-8a44-f0e5aaf26714"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "matrix", " ", "element", " ", "for", " ", "\[Pi]\[Omega]"}], 
    " ", "\[Rule]", " ", 
    RowBox[{"\[Pi]\[Rho]", " ", "\[Rule]", " ", 
     RowBox[{
     "3", "\[Pi]", " ", "using", " ", "the", " ", "Lagrangian", " ", "from", 
      " ", "the", " ", "paper", " ", "and", " ", "the", " ", "resulting", " ",
       "scalar", " ", "amplitude", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dropping", " ", "a", " ", "phase", " ", "factor"}], ")"}], 
       "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MatrixElement", "=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
       "\[ImaginaryI]", " ", "g\[Rho]\[Pi]\[Omega]", " ", 
        "g\[Rho]\[Pi]\[Pi]"}], 
       RowBox[{
        SuperscriptBox["F\[Pi]", "3"], 
        RowBox[{"(", 
         RowBox[{"s", "-", 
          SuperscriptBox["M\[Rho]", "2"]}], ")"}]}]], 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"LC", "[", 
         RowBox[{
         "\[Lambda]", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"p0", ",", "\[Mu]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"p0", ",", "\[Alpha]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{
          RowBox[{"pp", "+", "pm", "-", "p0"}], ",", "\[Nu]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{
          RowBox[{"pp", "+", "pm", "-", "p0"}], ",", "\[Beta]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"n", ",", "\[Gamma]"}], "]"}], 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"P3", "[", 
           RowBox[{
           "\[Mu]", ",", "\[Nu]", ",", "\[Lambda]", ",", "\[Mu]2", ",", 
            "\[Nu]2", ",", "\[Lambda]2"}], "]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"FV", "[", 
            RowBox[{"pp", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"FV", "[", 
            RowBox[{"pm", ",", "\[Nu]2"}], "]"}], 
           RowBox[{"FV", "[", 
            RowBox[{"pm", ",", "\[Lambda]2"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"FV", "[", 
            RowBox[{"pm", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"FV", "[", 
            RowBox[{"pp", ",", "\[Nu]2"}], "]"}], 
           RowBox[{"FV", "[", 
            RowBox[{"pp", ",", "\[Lambda]2"}], "]"}]}]}], ")"}]}], "]"}]}], "//",
      "FullSimplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ScalarAmplitude", "=", 
    RowBox[{
     FractionBox["MatrixElement", 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"LC", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
         "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"n", ",", "\[Mu]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"pp", ",", "\[Nu]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"pm", ",", "\[Alpha]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"p0", ",", "\[Beta]"}], "]"}]}], "]"}]], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.828417215211335*^9, 3.828417216850563*^9}, {
   3.8284172642103662`*^9, 3.828417366211219*^9}, {3.828417626538644*^9, 
   3.828417626969975*^9}, {3.8284179277222767`*^9, 3.828417928823011*^9}, {
   3.828422169967885*^9, 3.828422188224806*^9}, {3.828423165145842*^9, 
   3.8284231761176023`*^9}, {3.828423499464241*^9, 3.828423526146345*^9}, {
   3.828424999819953*^9, 3.828425061381586*^9}, {3.828425211963497*^9, 
   3.8284252164543743`*^9}, 3.828425334849613*^9, {3.828425413528474*^9, 
   3.8284254139616833`*^9}, {3.8284323841947517`*^9, 
   3.8284324026026583`*^9}, {3.828433279317809*^9, 3.828433286834284*^9}, {
   3.828433345754922*^9, 3.828433346278199*^9}, {3.828433922648356*^9, 
   3.828433932005514*^9}},ExpressionUUID->"94ba1661-e7c5-4af0-a920-\
2d3f335e55c5"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"120", " ", 
     SuperscriptBox["F\[Pi]", "3"], " ", 
     SuperscriptBox["M\[Rho]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M\[Rho]", "2"], "-", "s"}], ")"}]}]], 
   RowBox[{"g\[Rho]\[Pi]\[Pi]", " ", "g\[Rho]\[Pi]\[Omega]", " ", 
    SuperscriptBox[
     OverscriptBox["\[Epsilon]", "_"], 
     RowBox[{
      FormBox[
       OverscriptBox[
        FormBox["n",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       OverscriptBox[
        FormBox["p0",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       OverscriptBox[
        FormBox["pm",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       OverscriptBox[
        FormBox["pp",
         TraditionalForm], "_"],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"12", " ", 
        SuperscriptBox["M\[Pi]", "6"], " ", 
        SuperscriptBox["M\[Rho]", "2"]}]}], "+", 
      RowBox[{
       SuperscriptBox["M\[Pi]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"77", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "-", 
         RowBox[{"54", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["M\[Pi]", "2"], " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "-", 
         RowBox[{"27", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{"7", " ", 
       SuperscriptBox["M\[Rho]", "4"], " ", 
       SuperscriptBox["s", "2"]}], "-", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox["M\[Rho]", "4"], " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox["M\[Rho]", "2"], " ", 
       SuperscriptBox["s", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["MV", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"12", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", 
           SuperscriptBox["M\[Rho]", "2"]}]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["MV", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["M\[Pi]", "4"], " ", 
          SuperscriptBox["M\[Rho]", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["M\[Pi]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"17", " ", 
              SuperscriptBox["M\[Rho]", "4"]}]}], "+", 
            RowBox[{"30", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
         RowBox[{"s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"6", " ", 
              SuperscriptBox["M\[Rho]", "4"]}]}], "+", 
            RowBox[{"11", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
            RowBox[{"8", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["s", "4"]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828417370194206*^9, 3.82841745292073*^9, 3.828417493602933*^9, 
   3.828417540958899*^9, {3.828417611602213*^9, 3.828417633401846*^9}, 
   3.8284179295812683`*^9, 3.828422192630837*^9, {3.828423173470626*^9, 
   3.828423177601893*^9}, 3.82842352999771*^9, 3.828425062553783*^9, 
   3.828425219675516*^9, 3.828425336711445*^9, 3.8284254166116962`*^9, 
   3.8284324147006073`*^9, 3.828433254002997*^9, 3.828433292595973*^9, 
   3.828433347525964*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"c9cd94a7-8e71-4f90-ad3a-a45cbe2619dd"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"120", " ", 
     SuperscriptBox["F\[Pi]", "3"], " ", 
     SuperscriptBox["M\[Rho]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M\[Rho]", "2"], "-", "s"}], ")"}]}]], 
   RowBox[{"g\[Rho]\[Pi]\[Pi]", " ", "g\[Rho]\[Pi]\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["M\[Pi]", "6"], " ", 
       SuperscriptBox["M\[Rho]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["M\[Pi]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"77", " ", 
           SuperscriptBox["M\[Rho]", "4"]}]}], "+", 
         RowBox[{"54", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["M\[Pi]", "2"], " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "-", 
         RowBox[{"27", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["M\[Rho]", "4"], " ", 
       SuperscriptBox["s", "2"]}], "+", 
      RowBox[{"15", " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox["M\[Rho]", "4"], " ", 
       SuperscriptBox["z", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["M\[Rho]", "2"], " ", 
       SuperscriptBox["s", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["MV", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", 
          SuperscriptBox["M\[Rho]", "2"]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["MV", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"24", " ", 
           SuperscriptBox["M\[Pi]", "4"], " ", 
           SuperscriptBox["M\[Rho]", "2"]}]}], "+", 
         RowBox[{
          SuperscriptBox["M\[Pi]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"34", " ", 
             SuperscriptBox["M\[Rho]", "4"]}], "-", 
            RowBox[{"60", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox["M\[Rho]", "4"]}], "-", 
            RowBox[{"11", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["s", "4"]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828417370194206*^9, 3.82841745292073*^9, 3.828417493602933*^9, 
   3.828417540958899*^9, {3.828417611602213*^9, 3.828417633401846*^9}, 
   3.8284179295812683`*^9, 3.828422192630837*^9, {3.828423173470626*^9, 
   3.828423177601893*^9}, 3.82842352999771*^9, 3.828425062553783*^9, 
   3.828425219675516*^9, 3.828425336711445*^9, 3.8284254166116962`*^9, 
   3.8284324147006073`*^9, 3.828433254002997*^9, 3.828433292595973*^9, 
   3.828433347581339*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"70373c9c-8406-470a-ab40-34a3a8f194ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Project", " ", "out", " ", "the", " ", "F"}], "-", 
    RowBox[{"wave", " ", "in", " ", "the", " ", "s"}], "-", 
    RowBox[{"channel", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PWave", "=", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}], ")"}], "ScalarAmplitude"}], "/.", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", "\[Rule]", 
           RowBox[{"ArcCos", "[", "z", "]"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"FWave", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["7", "16"]}], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", 
             SuperscriptBox["z", "4"]}], "-", 
            RowBox[{"6", 
             SuperscriptBox["z", "2"]}], "+", "1"}], ")"}], 
          "ScalarAmplitude"}], "/.", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", "\[Rule]", 
           RowBox[{"ArcCos", "[", "z", "]"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.828422335661138*^9, 3.828422336040698*^9}, {
  3.828423194449551*^9, 3.828423195131048*^9}, {3.828423532654337*^9, 
  3.828423559637672*^9}, {3.8284249583954782`*^9, 3.828424981433434*^9}, {
  3.8284250757889833`*^9, 3.828425111953157*^9}, {3.828425239700315*^9, 
  3.828425263473763*^9}, {3.8284253806550817`*^9, 3.8284253826940317`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"8d0b2f1e-e6e3-4cad-b711-ab57839382a4"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"120", " ", 
     SuperscriptBox["F\[Pi]", "3"], " ", 
     SuperscriptBox["M\[Rho]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M\[Rho]", "2"], "-", "s"}], ")"}]}]], 
   RowBox[{"g\[Rho]\[Pi]\[Pi]", " ", "g\[Rho]\[Pi]\[Omega]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["M\[Pi]", "6"], " ", 
       SuperscriptBox["M\[Rho]", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["M\[Pi]", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"77", " ", 
           SuperscriptBox["M\[Rho]", "4"]}]}], "+", 
         RowBox[{"54", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["M\[Pi]", "2"], " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "-", 
         RowBox[{"27", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Kappa]", "2"], " ", 
       SuperscriptBox["M\[Rho]", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["M\[Rho]", "4"], " ", 
       SuperscriptBox["s", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["M\[Rho]", "2"], " ", 
       SuperscriptBox["s", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["MV", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", 
          SuperscriptBox["M\[Rho]", "2"]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox["M\[Rho]", "4"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["MV", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"24", " ", 
           SuperscriptBox["M\[Pi]", "4"], " ", 
           SuperscriptBox["M\[Rho]", "2"]}]}], "+", 
         RowBox[{
          SuperscriptBox["M\[Pi]", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"34", " ", 
             SuperscriptBox["M\[Rho]", "4"]}], "-", 
            RowBox[{"60", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             SuperscriptBox["M\[Rho]", "4"]}], "-", 
            RowBox[{"11", " ", 
             SuperscriptBox["M\[Rho]", "2"], " ", "s"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["s", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["s", "4"]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828422218602993*^9, 3.828422336299137*^9, 3.828423198769088*^9, {
   3.828423540213777*^9, 3.8284235644174747`*^9}, 3.828424986394874*^9, {
   3.828425086449191*^9, 3.8284251158294983`*^9}, 3.828425224373591*^9, 
   3.828425267641827*^9, 3.828425342814639*^9, 3.828425386285202*^9, 
   3.828425422920841*^9, 3.828432422606703*^9, 3.8284332613302307`*^9, 
   3.828433295901225*^9, 3.828433350283242*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"d213b2ab-7e68-4b15-bcff-2860e911b699"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"g\[Rho]\[Pi]\[Pi]", " ", "g\[Rho]\[Pi]\[Omega]", " ", 
    SuperscriptBox["\[Kappa]", "2"]}], 
   RowBox[{"60", " ", 
    SuperscriptBox["F\[Pi]", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["M\[Rho]", "2"], "-", "s"}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828422218602993*^9, 3.828422336299137*^9, 3.828423198769088*^9, {
   3.828423540213777*^9, 3.8284235644174747`*^9}, 3.828424986394874*^9, {
   3.828425086449191*^9, 3.8284251158294983`*^9}, 3.828425224373591*^9, 
   3.828425267641827*^9, 3.828425342814639*^9, 3.828425386285202*^9, 
   3.828425422920841*^9, 3.828432422606703*^9, 3.8284332613302307`*^9, 
   3.828433295901225*^9, 3.828433350458538*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"96662e4f-f06e-4927-adfc-2334d519bf3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Check", " ", "that", " ", "full", " ", "scalar", " ", "amplitude", " ", 
     "is", " ", "given", " ", "by", " ", "the", " ", "s"}], "-", 
    RowBox[{"channel", " ", "parts", " ", 
     RowBox[{"only", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ScalarAmplitude", "/.", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", "\[Rule]", 
        RowBox[{"ArcCos", "[", "z", "]"}]}], "}"}]}], ")"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PWave", "*", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"1", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "+", 
      RowBox[{"FWave", "*", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"LegendreP", "[", 
          RowBox[{"3", ",", "z"}], "]"}], ",", "z"}], "]"}]}]}], ")"}]}], "//",
    "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.8284250905905037`*^9, 3.8284251873776693`*^9}, {
  3.828425308954575*^9, 3.828425309558404*^9}, {3.828425353546432*^9, 
  3.828425370378158*^9}, {3.828425457368186*^9, 3.828425457609103*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"53ffff7e-8f6e-4cea-9a5e-6ddd9c6ef9ca"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828425187846422*^9, {3.8284252835193243`*^9, 3.828425311590884*^9}, {
   3.828425364105771*^9, 3.8284253715605*^9}, {3.828425433567464*^9, 
   3.828425457939323*^9}, 3.828433354946497*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"4dba254b-dd62-4aac-bf49-025197066100"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The \[Omega] \[Rule] 3\[Pi] F-Wave [dominated by ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["G", "^"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "aad288a0-65e6-43c3-afe1-8ea89cf44ad4"],
 "(s)]"
}], "Section",
 CellChangeTimes->{{3.828426054898848*^9, 3.828426069618476*^9}, {
  3.8284261138374443`*^9, 
  3.8284261454399033`*^9}},ExpressionUUID->"1d5859d3-c4a9-4fac-bd57-\
eaee7b76287d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Project", " ", "the", " ", "crossed"}], "-", 
    RowBox[{"channel", " ", "P"}], "-", 
    RowBox[{"Wave", " ", "terms", " ", "onto", " ", "the", " ", "F"}], "-", 
    RowBox[{"wave", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["7", "8"]}], 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", 
            SuperscriptBox["z", "4"]}], "-", 
           RowBox[{"6", 
            SuperscriptBox["z", "2"]}], "+", "1"}], ")"}], 
         FractionBox[
          SuperscriptBox["M\[Rho]", "2"], 
          RowBox[{
           SuperscriptBox["M\[Rho]", "2"], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"3", "s0"}], "-", "s", "+", 
             RowBox[{"\[Kappa]", "*", "z"}]}], "2"]}]]}], "/.", 
        RowBox[{"{", 
         RowBox[{"\[Kappa]", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              SuperscriptBox["M\[Rho]", "2"]}], "-", 
             RowBox[{"3", "s0"}], "+", "s"}], ")"}], "*", "\[Kappa]2"}]}], 
         "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "//", "Simplify"}],
    "//", "TrigToExp"}]}]], "Input",
 CellChangeTimes->{{3.828426089774967*^9, 3.828426105989259*^9}, {
  3.828426212196293*^9, 3.828426288039753*^9}, {3.828426430645763*^9, 
  3.828426449394809*^9}, {3.828426555195038*^9, 3.828426556276471*^9}, {
  3.8284271080324917`*^9, 3.828427141899589*^9}, {3.828427235874061*^9, 
  3.828427255823159*^9}, {3.8284282875012903`*^9, 3.828428287680423*^9}, {
  3.828434342069137*^9, 3.828434344905652*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"7e1a6ad8-c805-436c-866a-47e61c822b5e"],

Cell[BoxData[
 FormBox[
  RowBox[{"ConditionalExpression", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"7", " ", 
      SuperscriptBox["M\[Rho]", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"26", " ", 
          SuperscriptBox["\[Kappa]2", "3"]}]}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Kappa]2", "4"], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["\[Kappa]2", "2"]}], "+", "5"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"log", "(", 
            RowBox[{"\[Kappa]2", "+", "1"}], ")"}], "-", 
           RowBox[{"log", "(", 
            RowBox[{"1", "-", "\[Kappa]2"}], ")"}]}], ")"}]}], "+", 
        RowBox[{"30", " ", "\[Kappa]2"}]}], ")"}]}], 
     RowBox[{"12", " ", 
      SuperscriptBox["\[Kappa]2", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["M\[Rho]", "2"]}], "+", "s", "-", 
        RowBox[{"3", " ", "s0"}]}], ")"}]}]], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "<", 
      RowBox[{"Re", "(", "\[Kappa]2", ")"}], "<", "0"}], "\[Or]", 
     RowBox[{"0", "<", 
      RowBox[{"Re", "(", "\[Kappa]2", ")"}], "<", "1"}], "\[Or]", 
     RowBox[{"\[Kappa]2", "\[NotElement]", 
      TemplateBox[{},
       "Reals"]}]}]}], "]"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8284263890312634`*^9, 3.828426453233776*^9, 3.8284265590299788`*^9, {
   3.828427110867303*^9, 3.828427144738809*^9}, {3.828427239287676*^9, 
   3.828427258684208*^9}, 3.8284282903338823`*^9, 3.828434323762764*^9, 
   3.8284343576974783`*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"f12ec048-746c-4f77-85d1-68790c0e8145"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Check", " ", "that", " ", "the", " ", "obtained", " ", "result", " ", 
    "is", " ", "equivalent", " ", "to", " ", "the", " ", "equation", " ", 
    "from", " ", "the", " ", "paper", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "see", " ", "also", " ", "the", " ", "handwritten", " ", "notes"}], 
      ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "2"}], 
        SuperscriptBox["M\[Rho]", "2"]}], 
       RowBox[{
        SuperscriptBox["M\[Rho]", "2"], "-", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", "s0"}], "-", "s"}], ")"}]}]}]], 
      FractionBox["7", 
       RowBox[{"8", 
        SuperscriptBox["\[Kappa]2", "4"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"5", "-", 
           RowBox[{"6", 
            SuperscriptBox["\[Kappa]2", "2"]}], "+", 
           SuperscriptBox["\[Kappa]2", "4"]}], 
          RowBox[{"2", "\[Kappa]2"}]], 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "+", "\[Kappa]2"}], 
           RowBox[{"1", "-", "\[Kappa]2"}]], "]"}]}], "-", 
        FractionBox[
         RowBox[{"15", "-", 
          RowBox[{"13", 
           SuperscriptBox["\[Kappa]2", "2"]}]}], "3"]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["M\[Rho]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"26", " ", 
           SuperscriptBox["\[Kappa]2", "3"]}]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Kappa]2", "4"], "-", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[Kappa]2", "2"]}], "+", "5"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"\[Kappa]2", "+", "1"}], "]"}], "-", 
            RowBox[{"Log", "[", 
             RowBox[{"1", "-", "\[Kappa]2"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"30", " ", "\[Kappa]2"}]}], ")"}]}], 
      RowBox[{"12", " ", 
       SuperscriptBox["\[Kappa]2", "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Rho]", "2"]}], "+", "s", "-", 
         RowBox[{"3", " ", "s0"}]}], ")"}]}]]}], "//", "Simplify"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.8284285368946667`*^9, 3.828428672627407*^9}, {
  3.8284289321942673`*^9, 
  3.828428952943659*^9}},ExpressionUUID->"e0b2468a-66a9-432d-a04e-\
9288d94abb32"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828428620305271*^9, {3.828428657968788*^9, 3.828428672918996*^9}},
 CellLabel->
  "Out[138]=",ExpressionUUID->"7a72c0aa-9c16-4ff1-8234-63bcfc049cf5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{950, 603},
WindowMargins->{{-1058, Automatic}, {-41, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 172, 3, 97, "Title",ExpressionUUID->"8edda97e-8cfc-496f-b52d-45bda659245b"],
Cell[755, 27, 946, 27, 84, "Input",ExpressionUUID->"2931db4e-1d93-4bff-88fa-b67d831e257d"],
Cell[CellGroupData[{
Cell[1726, 58, 155, 3, 69, "Section",ExpressionUUID->"dc64ec20-ed38-4b6d-acca-37488d9e6618"],
Cell[1884, 63, 526, 13, 41, "Input",ExpressionUUID->"6246f7aa-8893-4fa1-beca-c664aaada592"],
Cell[2413, 78, 927, 26, 128, "Input",ExpressionUUID->"b1d22be1-127e-4293-8c2f-ed4f8fcd7c51"],
Cell[CellGroupData[{
Cell[3365, 108, 179, 3, 34, "Subsection",ExpressionUUID->"0d338ae3-42ef-4591-ba2b-4c8e9c2c4c6a"],
Cell[CellGroupData[{
Cell[3569, 115, 2314, 71, 314, "Input",ExpressionUUID->"0c523243-59aa-4495-aedd-c82b0b0cf463"],
Cell[5886, 188, 1495, 41, 69, "Output",ExpressionUUID->"de00e585-0964-4aa6-a44c-6781b36562d7"],
Cell[7384, 231, 534, 15, 74, "Output",ExpressionUUID->"c484e758-cb74-4d71-8136-30911bf4f477"],
Cell[7921, 248, 507, 14, 74, "Output",ExpressionUUID->"fe7d861b-ce04-479b-8e86-bd2d156d7fcf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8465, 267, 1610, 46, 235, "Input",ExpressionUUID->"d831104f-b9bf-48e9-b9db-3a129a0316a5"],
Cell[10078, 315, 846, 25, 57, "Output",ExpressionUUID->"da9987df-a3fc-4dfe-b80e-69e6f09d9f79"],
Cell[10927, 342, 363, 7, 60, "Output",ExpressionUUID->"cca7260d-5003-400a-a350-c267e94c49cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11327, 354, 1581, 46, 235, "Input",ExpressionUUID->"8b3ea4c8-ffd2-4a08-bb10-07d64f07a2d2"],
Cell[12911, 402, 869, 25, 57, "Output",ExpressionUUID->"cb57bd3e-2527-4527-9241-e0351d9c34fc"],
Cell[13783, 429, 382, 7, 60, "Output",ExpressionUUID->"26b0939d-ab63-4a99-91d6-6c8671ed136d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14214, 442, 231, 4, 34, "Subsection",ExpressionUUID->"75c59fb5-d130-4b8a-aad3-eed703cf8fd8"],
Cell[CellGroupData[{
Cell[14470, 450, 261, 6, 63, "Input",ExpressionUUID->"82136410-855c-4667-abc6-1a1943bb156e"],
Cell[CellGroupData[{
Cell[14756, 460, 2543, 68, 30, "Print",ExpressionUUID->"797e3dc4-c978-4beb-9879-b380b06128d9"],
Cell[17302, 530, 1281, 31, 30, "Print",ExpressionUUID->"8b25194d-4913-426c-9699-1a4ad147515f"],
Cell[18586, 563, 1287, 34, 30, "Print",ExpressionUUID->"0d66a81a-adac-46ec-aa97-5a24dd6e9220"],
Cell[19876, 599, 439, 9, 27, "Print",ExpressionUUID->"eae08e53-f31f-4cc9-a0c3-a952eeda8764"],
Cell[20318, 610, 440, 9, 27, "Print",ExpressionUUID->"c8feefdf-496a-4af2-a57f-4a36ff128c33"],
Cell[20761, 621, 429, 9, 27, "Print",ExpressionUUID->"91e6fcfd-6041-4ec8-8d7b-e64f0195334a"]
}, Open  ]]
}, Open  ]],
Cell[21217, 634, 3083, 82, 316, "Input",ExpressionUUID->"a65d4b1a-5aa3-4286-8393-6f04b911490f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24349, 722, 158, 3, 69, "Section",ExpressionUUID->"02f35dc7-29ed-42b6-ab80-be8ece5b3f84"],
Cell[CellGroupData[{
Cell[24532, 729, 1284, 32, 84, "Input",ExpressionUUID->"54470584-aeeb-41ba-ba98-d60c8b1ac79d"],
Cell[25819, 763, 914, 26, 57, "Output",ExpressionUUID->"ebd5f9fd-b89b-41c0-ba8e-090397a6fe71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26770, 794, 1405, 35, 84, "Input",ExpressionUUID->"3ed7efb6-dbe9-44af-bbc5-34bbf8c68833"],
Cell[28178, 831, 1360, 37, 57, "Output",ExpressionUUID->"22612353-88af-4454-862b-e0750d2d89ab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29575, 873, 948, 22, 84, "Input",ExpressionUUID->"a59187d0-b15b-4926-8e5d-5ed22a517b7c"],
Cell[30526, 897, 851, 21, 61, "Output",ExpressionUUID->"f02ecdad-caed-48d0-bd7b-6751e6d6bf16"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31426, 924, 179, 3, 69, "Section",ExpressionUUID->"33734ebc-350e-4086-a23e-26078219fe39"],
Cell[CellGroupData[{
Cell[31630, 931, 2274, 63, 181, "Input",ExpressionUUID->"a9879273-914a-4072-b456-988d473abb21"],
Cell[33907, 996, 814, 21, 133, "Output",ExpressionUUID->"799d062c-55e2-4484-b71d-160e87fe3703"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34758, 1022, 1680, 47, 134, "Input",ExpressionUUID->"40761ede-e6b2-4a9d-b199-db08f64bde40"],
Cell[36441, 1071, 814, 21, 133, "Output",ExpressionUUID->"0d3757d0-8916-4289-addf-f8feb25423d9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37304, 1098, 158, 3, 69, "Section",ExpressionUUID->"6ed9556a-46d7-4e9f-b685-443e4e689f74"],
Cell[CellGroupData[{
Cell[37487, 1105, 1175, 29, 100, "Input",ExpressionUUID->"9af5e80b-766c-4c1c-acbc-b2c3c2aaac85"],
Cell[38665, 1136, 179, 3, 37, "Output",ExpressionUUID->"a68bc149-598f-4eba-b57d-54da0f914d8d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38893, 1145, 175, 3, 69, "Section",ExpressionUUID->"65740e1b-ef99-4e57-ad42-b67052d253f5"],
Cell[CellGroupData[{
Cell[39093, 1152, 1316, 38, 101, "Input",ExpressionUUID->"be7a42aa-5f0b-46df-a96e-b1f118922af5"],
Cell[40412, 1192, 177, 3, 37, "Output",ExpressionUUID->"8de141c1-354b-46b6-a36b-03fe52078f10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40626, 1200, 2196, 62, 181, "Input",ExpressionUUID->"01af6bc1-0484-4fb3-b1c7-0c9a40f69d19"],
Cell[42825, 1264, 816, 21, 133, "Output",ExpressionUUID->"4e038b5a-e174-417b-b8fc-d68b55111f3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43678, 1290, 2458, 78, 281, "Input",ExpressionUUID->"1aec6083-bdc8-48d8-92aa-2b9e3d8cb489"],
Cell[46139, 1370, 234, 5, 37, "Output",ExpressionUUID->"f33487fd-f652-4591-80c8-d60379ab6e79"],
Cell[46376, 1377, 232, 5, 37, "Output",ExpressionUUID->"5ecdb35e-6669-422b-97a4-3d3579161a1a"],
Cell[46611, 1384, 232, 5, 37, "Output",ExpressionUUID->"6181529f-1152-4953-8a28-c3af1aa203c7"],
Cell[46846, 1391, 232, 5, 37, "Output",ExpressionUUID->"8c1b5abb-6856-4a77-8278-952c39714ca2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47127, 1402, 477, 11, 70, "Section",ExpressionUUID->"3b9fbab5-24e3-45f6-8d03-8cdf20ee57c3"],
Cell[CellGroupData[{
Cell[47629, 1417, 260, 6, 63, "Input",ExpressionUUID->"b1b0216a-fc89-4fc1-b18f-ac77f3c820ef"],
Cell[CellGroupData[{
Cell[47914, 1427, 2544, 68, 30, "Print",ExpressionUUID->"38091af1-4e2e-4f97-b5f4-311fafd1d185"],
Cell[50461, 1497, 1282, 31, 30, "Print",ExpressionUUID->"c450ff93-6164-47f9-9b2d-684954385ea7"],
Cell[51746, 1530, 1288, 34, 30, "Print",ExpressionUUID->"5a3ca59e-8fb1-4957-970f-cd5efaca09a2"],
Cell[53037, 1566, 438, 9, 27, "Print",ExpressionUUID->"56466836-29c3-41f3-9977-235ce98b4b91"],
Cell[53478, 1577, 438, 9, 27, "Print",ExpressionUUID->"dca2caec-9e99-4e44-b796-80cccd03cb05"],
Cell[53919, 1588, 426, 9, 27, "Print",ExpressionUUID->"b9ab5705-82d0-4568-9993-8ff789872872"]
}, Open  ]]
}, Open  ]],
Cell[54372, 1601, 2621, 72, 357, "Input",ExpressionUUID->"5c280818-6d7a-4146-aec5-55c465ba2f43"],
Cell[56996, 1675, 948, 29, 151, "Input",ExpressionUUID->"adb2ccde-9ddf-4444-b155-5542fb001556"],
Cell[57947, 1706, 1825, 44, 168, "Input",ExpressionUUID->"9f4eb6fe-f6e3-41e8-957b-b91c5cf44ae1"],
Cell[59775, 1752, 694, 17, 63, "Input",ExpressionUUID->"d9c26f88-75ef-4e44-a06a-e9ca3ed8c62c"],
Cell[CellGroupData[{
Cell[60494, 1773, 1024, 23, 105, "Input",ExpressionUUID->"fe55d74f-e8fc-4347-a4be-cb97198f4f0c"],
Cell[61521, 1798, 400, 8, 37, "Output",ExpressionUUID->"5a85ce11-0c20-4da4-ae2b-f6f2d851d17f"],
Cell[61924, 1808, 623, 15, 37, "Output",ExpressionUUID->"440a1b39-c88c-4e9e-a44e-bd7de36e53e5"]
}, Open  ]],
Cell[62562, 1826, 7397, 201, 432, "Input",ExpressionUUID->"bf81b9fe-8589-43db-8a44-f0e5aaf26714"],
Cell[CellGroupData[{
Cell[69984, 2031, 3954, 98, 258, "Input",ExpressionUUID->"94ba1661-e7c5-4af0-a920-2d3f335e55c5"],
Cell[73941, 2131, 4321, 122, 117, "Output",ExpressionUUID->"c9cd94a7-8e71-4f90-ad3a-a45cbe2619dd"],
Cell[78265, 2255, 3710, 97, 117, "Output",ExpressionUUID->"70373c9c-8406-470a-ab40-34a3a8f194ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82012, 2357, 2026, 54, 139, "Input",ExpressionUUID->"8d0b2f1e-e6e3-4cad-b711-ab57839382a4"],
Cell[84041, 2413, 3624, 95, 117, "Output",ExpressionUUID->"d213b2ab-7e68-4b15-bcff-2860e911b699"],
Cell[87668, 2510, 839, 18, 66, "Output",ExpressionUUID->"96662e4f-f06e-4927-adfc-2334d519bf3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88544, 2533, 1256, 32, 84, "Input",ExpressionUUID->"53ffff7e-8f6e-4cea-9a5e-6ddd9c6ef9ca"],
Cell[89803, 2567, 348, 6, 37, "Output",ExpressionUUID->"4dba254b-dd62-4aac-bf49-025197066100"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[90200, 2579, 436, 12, 71, "Section",ExpressionUUID->"1d5859d3-c4a9-4fac-bd57-eaee7b76287d"],
Cell[CellGroupData[{
Cell[90661, 2595, 1917, 50, 118, "Input",ExpressionUUID->"7e1a6ad8-c805-436c-866a-47e61c822b5e"],
Cell[92581, 2647, 1745, 46, 67, "Output",ExpressionUUID->"f12ec048-746c-4f77-85d1-68790c0e8145"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94363, 2698, 2710, 79, 168, "Input",ExpressionUUID->"e0b2468a-66a9-432d-a04e-9288d94abb32"],
Cell[97076, 2779, 230, 5, 37, "Output",ExpressionUUID->"7a72c0aa-9c16-4ff1-8234-63bcfc049cf5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

